# 🐼 CoolPandas

![main-unit-testing workflow](https://github.com/adocquin/coolpandas/actions/workflows/main-unit-testing.yaml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/adocquin/coolpandas/badge.svg)](https://coveralls.io/github/adocquin/coolpandas)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A Python package for Exploratory Data Analysis.

## Development

### Setup

Execute:

```bash
pip install -r requirements.txt
pre-commit install
pre-commit autoupdate
```
